pygeodesy.auxilats._CX_Rs

Package pygeodesy :: Package auxilats :: Module _CX_Rs |
[frames] | no frames]

# Module _CX_Rs

(INTERNAL) Classes `_Rcoeffs`, `_Rdict` and `_Rtuple` to store the deferred Python versions of coefficients from Karney's C++ class AuxLatitude.

Copyright (C) Charles Karney (2022-2024) Karney@Alum.MIT.edu> and licensed under the MIT/X11 License. For more information, see <https://GeographicLib.SourceForge.io>.

Version: 25.05.12